master a3d43a12a40: Spelling fixes, mostly UK →US

Paul Eggert <[email protected]>
Newsgroups gmane.emacs.diffs
Message-ID <[email protected]>
branch: master
commit a3d43a12a4060430c92145e4c53431ccf20bae58
Author: Paul Eggert <[email protected]>
Commit: Paul Eggert <[email protected]>

    Spelling fixes, mostly UK→US
    
    * lisp/custom.el (custom--sort-vars-1):
    * lisp/language/indonesian.el:
    Use ‘dependent’ rather than British spelling in internal names.
    In indonesian.el, the ‘-ant’ spelling was incorrect even for UK
    spelling as it was an adjective not a noun.
    * lisp/emacs-lisp/package-vc.el (package-vc--clone):
    Fix typo in spelling of README-elpa file name.
    * lisp/vc/vc.el (vc-revert):
    Use American instead of British spelling in diagnostics.
    * m4/texinfo.m4 (gl_TEXINFO_INDEXING_IS_LOCALE_DEPENDENT):
    Rename from gl_TEXINFO_INDEXING_IS_LOCALE_DEPENDANT.  Use changed.
---
 ChangeLog.3                                 |   6 +-
 ChangeLog.4                                 |   6 +-
 ChangeLog.5                                 | 112 ++++++++++++++--------------
 admin/nt/dist-build/README-windows-binaries |   4 +-
 admin/nt/dist-build/build-dep-zips.py       |   8 +-
 doc/lispref/display.texi                    |   2 +-
 doc/lispref/parsing.texi                    |   2 +-
 doc/misc/ChangeLog.1                        |   2 +-
 doc/misc/org.org                            |   2 +-
 etc/ERC-NEWS                                |   2 +-
 etc/NEWS.31                                 |   2 +-
 lib-src/emacsclient.c                       |   4 +-
 lisp/calendar/diary-icalendar.el            |   2 +-
 lisp/calendar/icalendar-parser.el           |   2 +-
 lisp/cedet/semantic/db-find.el              |   6 +-
 lisp/custom.el                              |  18 ++---
 lisp/emacs-lisp/package-activate.el         |   2 +-
 lisp/emacs-lisp/package-vc.el               |   2 +-
 lisp/emacs-lisp/package.el                  |   2 +-
 lisp/emacs-lisp/rx.el                       |   2 +-
 lisp/erc/erc-common.el                      |   2 +-
 lisp/language/indonesian.el                 |  20 ++---
 lisp/obsolete/gnus-dbus.el                  |   4 +-
 lisp/org/org-element.el                     |   2 +-
 lisp/org/ox-latex.el                        |   4 +-
 lisp/progmodes/compile.el                   |   2 +-
 lisp/progmodes/eglot.el                     |   2 +-
 lisp/subr.el                                |   2 +-
 lisp/textmodes/fill.el                      |   2 +-
 lisp/textmodes/markdown-ts-mode-x.el        |   4 +-
 lisp/vc/vc.el                               |   2 +-
 m4/texinfo.m4                               |  12 +--
 src/term.c                                  |   2 +-
 src/treesit.c                               |   2 +-
 src/window.c                                |   2 +-
 src/xdisp.c                                 |   2 +-
 src/xterm.c                                 |   2 +-
 37 files changed, 128 insertions(+), 128 deletions(-)

diff --git a/ChangeLog.3 b/ChangeLog.3
index e34e7bfc6f4..e4b8d60bf1b 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -15670,7 +15670,7 @@
 	* lisp/progmodes/cc-mode.el (c-depropertize-CPP): Test for general ml strings
 	rather than C++ raw strings.
 	(c-unescaped-nls-in-string-p): Handle languages with ml strings.
-	(c-clear-string-fences): Fix bug with wrong parenthesisation.
+	(c-clear-string-fences): Fix bug with wrong parenthesization.
 	(c-before-change-check-unbalanced-strings)
 	(c-after-change-mark-abnormal-strings, c-after-change-escape-NL-in-string):
 	Adapt for multi-line strings.
@@ -17441,7 +17441,7 @@
 
 2021-07-30  Mattias Engdegård  <[email protected]>
 
-	Simplify lexical let-optimisations
+	Simplify lexical let-optimizations
 
 	Ensure in cconv that let-bindings have the normal form (VAR EXPR)
 	where VAR is a valid variable name, so that we don't need to keep
@@ -57196,7 +57196,7 @@
 
 	* lisp/progmodes/compile.el (compilation-error-regexp-alist-alist):
 	'javac': Column numbers are 1-based by default; remove subtraction and
-	η-reduce.  Translate regexp to rx (mechanised).
+	η-reduce.  Translate regexp to rx (mechanized).
 	* test/lisp/progmodes/compile-tests.el (compile-tests--test-regexps-data):
 	Adapt 'javac' test cases to the change.
 
diff --git a/ChangeLog.4 b/ChangeLog.4
index 0624cc5a199..1a5f9f1b23a 100644
--- a/ChangeLog.4
+++ b/ChangeLog.4
@@ -672,7 +672,7 @@
 	format.
 
 	This patch fixes various problems preventing this script from
-	working. The job of this script is to collect Emacs' dependanicies
+	working. The job of this script is to collect Emacs' dependencies
 	and the (MSYS2/MinGW64) source archives for dependencies
 	(including 2nd etc. order dependencies) into zip archives.  GPL
 	requires distributing such archives (along with Emacs' own
@@ -99218,7 +99218,7 @@
 	granular.
 
 	* lisp/progmodes/java-ts-mode.el (java-ts-mode): Use regexp-opt to
-	distinguish more granularly.
+	distinguish in more detail.
 
 2022-12-09  Randy Taylor  <[email protected]>
 
@@ -114450,7 +114450,7 @@
 	Make Gnus respect mode-line-buffer-identification-keymap
 
 	* lisp/gnus/gnus-group.el (gnus-group-set-mode-line): Use
-	'propertized-buffer-identification' to buttonise and fontify the
+	'propertized-buffer-identification' to buttonize and fontify the
 	buffer name.
 	* lisp/gnus/gnus-sum.el (gnus-set-mode-line):
 	* lisp/gnus/gnus.el (gnus-mode-line-buffer-identification): Adjust
diff --git a/ChangeLog.5 b/ChangeLog.5
index 714fbd19662..40b653b1eb4 100644
--- a/ChangeLog.5
+++ b/ChangeLog.5
@@ -963,7 +963,7 @@
 
 	* lisp/treesit.el:
 	(treesit--embed-languages-need-full-parse): New variable.
-	(treesit--set-embed-ranges): Reparse full range if the langauge
+	(treesit--set-embed-ranges): Reparse full range if the language
 	needs it.
 
 2026-06-19  Stephen Berman  <[email protected]>
@@ -1302,7 +1302,7 @@
 	* src/xselect.c (x_display_selection_waiting_message):
 	(x_cancel_atimer):
 	(x_get_foreign_selection): Use a pointer to a timer variable, which is
-	cleared when the timer runs or is otherwise cancelled.  Don't cancel
+	cleared when the timer runs or is otherwise canceled.  Don't cancel
 	the timer twice.
 
 2026-06-06  Pip Cet  <[email protected]>
@@ -2752,7 +2752,7 @@
 	call into the backend to gather the VC state.  Since this function is
 	also called from another context, where the requirements are less clear,
 	keeping current smenatics in that situation seemed prudent, so the new
-	behaviour is activate with a new optional parameter.
+	behavior is activate with a new optional parameter.
 
 	* lisp/vc/vc-dir.el (vc-dir-resynch-file): Call
 	vc-dir-recompute-file-state with truename=t.
@@ -3936,7 +3936,7 @@
 
 2026-04-30  Vladimir Kazanov  <[email protected]>
 
-	Add ERT coverage for read_key_sequence behaviour
+	Add ERT coverage for read_key_sequence behavior
 
 	* test/src/keyboard-tests.el
 	(keyboard-tests--rks-fake-posn)
@@ -6419,7 +6419,7 @@
 	Implement new Dired handling of errors from 'ls'
 
 	The error messages are now displayed in a popped up buffer instead
-	of being output in the Dired buffer and signalling an error.  The
+	of being output in the Dired buffer and signaling an error.  The
 	file name bounds in Dired entries are now determined solely by the
 	offsets calculated by 'ls' with the --dired option and
 	consequently Dired now reliably recognizes file names that contain
@@ -7991,10 +7991,10 @@
 
 2026-03-03  Mattias Engdegård  <[email protected]>
 
-	Faster JSON string serialisation (bug#80529)
+	Faster JSON string serialization (bug#80529)
 
 	* src/json.c (json_out_string):
-	Optimise for runs of non-special ASCII chars.
+	Optimize for runs of non-special ASCII chars.
 
 	This seems to be a a substantial performance gain for long strings but a
 	smaller regression for short strings (up to 6 chars or thereabouts,
@@ -8269,7 +8269,7 @@
 
 2026-02-28  Mattias Engdegård  <[email protected]>
 
-	Implement string> as a compiler macro instead of an optimisation
+	Implement string> as a compiler macro instead of an optimization
 
 	This doesn't affect the generated code.
 
@@ -8493,10 +8493,10 @@
 
 2026-02-26  Mattias Engdegård  <[email protected]>
 
-	Simplify peephole optimisation rule
+	Simplify peephole optimization rule
 
 	* lisp/emacs-lisp/byte-opt.el (byte-optimize-lapcode):
-	Remove some obsolete dynamic variable optimisations that no longer
+	Remove some obsolete dynamic variable optimizations that no longer
 	improve any code.  Fix broken logging (thanks Pip).
 
 2026-02-26  Yuan Fu  <[email protected]>
@@ -8580,7 +8580,7 @@
 	Fix eglot-tests on MacOS (bug#80479)
 
 	* test/lisp/progmodes/eglot-tests.el (eglot--call-with-fixture):
-	Normalise 'temporary-file-directory' to stave off problems that
+	Normalize 'temporary-file-directory' to stave off problems that
 	occur when it contains symlinks, which is common on MacOS.
 
 2026-02-24  Mattias Engdegård  <[email protected]>
@@ -9230,7 +9230,7 @@
 
 2026-02-20  Mattias Engdegård  <[email protected]>
 
-	Optimise closed-over variables earlier
+	Optimize closed-over variables earlier
 
 	* lisp/emacs-lisp/byte-opt.el (byte-optimize-form-code-walker):
 	Treat 'internal-get-closed-var' as a special form and delete it in
@@ -9238,7 +9238,7 @@
 
 2026-02-20  Mattias Engdegård  <[email protected]>
 
-	Remove two obsolete peephole optimisation rules
+	Remove two obsolete peephole optimization rules
 
 	* lisp/emacs-lisp/byte-opt.el (byte-optimize-lapcode):
 	Remove two rules: the first could sometimes skip a varref in a loop;
@@ -9247,7 +9247,7 @@
 	from the top to the bottom of a loop but depended on the first to work.
 
 	Both were quite slow, easily measurable when compiling big files, and
-	arguably O(n³) which isn't very good for a peephole optimisation.
+	arguably O(n³) which isn't very good for a peephole optimization.
 
 2026-02-20  Sean Whitton  <[email protected]>
 
@@ -10375,7 +10375,7 @@
 
 2026-02-11  Mattias Engdegård  <[email protected]>
 
-	Better 'prog1' optimisation
+	Better 'prog1' optimization
 
 	* lisp/emacs-lisp/byte-opt.el (byte-optimize-form-code-walker):
 	Always evaporate 'prog1' when the tail is effect-free, even
@@ -10844,7 +10844,7 @@
 	(package--autosuggest-find-candidates)
 	(package--autosugest-line-format, package-autosuggest-face)
 	(package--autosuggest-after-change-mode, package-autosuggest):
-	Remove definitions needed to recognise suggestions from here.
+	Remove definitions needed to recognize suggestions from here.
 
 	* lisp/emacs-lisp/package-activate.el (package-autosuggest-style)
 	(package--autosuggest-database, package--autosuggest-suggested)
@@ -10892,7 +10892,7 @@
 	Eglot: fix thinko in eglot--async-request
 
 	Just because a specific request of a specific "hint" is
-	cancelled doesn't mean we can cancel the other's too.  Also
+	canceled doesn't mean we can cancel the other's too.  Also
 	eglot-advertise-cancellation = nil was subtly broken.
 
 	This manifested itself mostly in Eglot semantic tokens.
@@ -11331,7 +11331,7 @@
 
 	* lisp/progmodes/eglot.el (eglot-server-programs): Use "elp" for erlang-mode.
 
-	erlang_ls has been archived in favour of erlang-language-platform.
+	erlang_ls has been archived in favor of erlang-language-platform.
 	Suggested by Alan & Kim Zimmerman <[email protected]> (bug#79943).
 
 2026-01-30  Juri Linkov  <[email protected]>
@@ -11991,11 +11991,11 @@
 
 2026-01-23  Mattias Engdegård  <[email protected]>
 
-	* lisp/emacs-lisp/pcase.el (pcase--macroexpand): Normalise atom etc.
+	* lisp/emacs-lisp/pcase.el (pcase--macroexpand): Normalize atom etc.
 
 	Transform (pred P) for P in {atom, nlistp, identity, not} into
 	predicates that pcase already understands in type terms.
-	This doesn't affect the behaviour but generates better code.
+	This doesn't affect the behavior but generates better code.
 
 2026-01-23  Mattias Engdegård  <[email protected]>
 
@@ -12237,7 +12237,7 @@
 
 	It was completely broken, with a cancel being set for every sent (and
 	probably already received) async request, and no actual discarding
-	of the response of a cancelled request.
+	of the response of a canceled request.
 
 	* lisp/progmodes/eglot.el (eglot--async-request): Fix cancellation
 	of async requests.
@@ -14054,7 +14054,7 @@
 	associated alist entries `tab-name' and `tab-group'.
 
 	* lisp/tab-bar.el (display-buffer-in-tab): Restructure docstring for
-	clarity.  Describe the `reusable-frames' behaviour first (as if it finds
+	clarity.  Describe the `reusable-frames' behavior first (as if it finds
 	a frame with a suitable tab then the `tab-name' entry is not used).
 
 	(display-buffer-in-new-tab): Use consistent wording.
@@ -14157,7 +14157,7 @@
 
 2026-01-01  Mattias Engdegård  <[email protected]>
 
-	Clean up a lapcode peephole optimisation rule
+	Clean up a lapcode peephole optimization rule
 
 	* lisp/emacs-lisp/byte-opt.el (byte-optimize-lapcode):
 	Clean up and simplify an old jump-to-conditional-jump rule that was
@@ -14618,7 +14618,7 @@
 	* lisp/subr.el (split-string):
 
 	Make it clear that the SEPARATORS argument should not match the empty
-	string, since the behaviour was entirely an artefact of the original
+	string, since the behavior was entirely an artefact of the original
 	implementation in this case; it makes little sense otherwise.
 
 	Clean up the examples for conciseness and do not waste space on
@@ -14629,8 +14629,8 @@
 	Various split-string improvements
 
 	* lisp/subr.el (split-string):
-	Fix quadratic behaviour in (split-string "x:x:x..." ":" nil " +").
-	General code reorganisation for speed and reduced allocation.
+	Fix quadratic behavior in (split-string "x:x:x..." ":" nil " +").
+	General code reorganization for speed and reduced allocation.
 	Fix a regexp bug; eg, (split-string "A;B" "," nil ";\\|:")
 
 	* test/lisp/subr-tests.el (subr-test-split-string):
@@ -14897,7 +14897,7 @@
 
 2025-12-22  Mattias Engdegård  <[email protected]>
 
-	Recognise %b and %B in compile-time format string checker
+	Recognize %b and %B in compile-time format string checker
 
 	* lisp/emacs-lisp/bytecomp.el (byte-compile-format-warn): Add b and B.
 
@@ -16137,7 +16137,7 @@
 	(package-vc-tests-packages): Rename test packages to avoid
 	suffix being treated as a version number by
 	`package--description-file'.
-	(package-vc-tests-add): Ensure suffix capitalisation remains as
+	(package-vc-tests-add): Ensure suffix capitalization remains as
 	original when calling `replace-regexp-in-string'.
 	(package-vc-tests-create-repository): Fix typo in temporary
 	email and use a reserved TLD.
@@ -16542,7 +16542,7 @@
 	* lisp/progmodes/antlr-mode.el: Correct indentation of rule headers.
 	(antlr-indent-line): When looking for the end of a rule header, do
 	not stop at colon if that is followed by another one, because this
-	the scope name of a preceeding grammar action.
+	the scope name of a preceding grammar action.
 
 	* lisp/progmodes/antlr-mode.el: Support more action languages.
 	(antlr-language-alist): Add entries for C, Delphi, JavaScript,
@@ -17893,7 +17893,7 @@
 	Therefore it's better for the ergonomics of this commonly used command
 	to leave the code as it was and simply rely on C-n to bring in the
 	default value (which is the current symbol name), instead of forcing
-	users accustomed to the previous behaviour remember to press sth like
+	users accustomed to the previous behavior remember to press sth like
 	M-DEL to clean the input.
 
 	* lisp/progmodes/eglot.el (eglot-rename): Tweak.
@@ -18431,7 +18431,7 @@
 	* lisp/emacs-lisp/cond-star.el (cond*-convert-condition): Bind
 	unused values to fresh symbols, to avoid the compiler warning
 	that a symbol starting with an underscore is accessed later on.
-	This mirrors the behaviour of `if-let*' and family.
+	This mirrors the behavior of `if-let*' and family.
 
 2025-11-24  Juri Linkov  <[email protected]>
 
@@ -20637,9 +20637,9 @@
 	(rcirc-markup-attributes): Delete markup codes straight after
 	processing it, to correctly handle toggling codes.  E.g. when
 	processing the message "one ^Btwo^B three", we previously
-	recognised the first interval "^Btwo^B" and moved over the ^B.
+	recognized the first interval "^Btwo^B" and moved over the ^B.
 	Searching for the next range to markup, we would now falsely
-	recognise "^B three" to be another markup range, instead of it
+	recognize "^B three" to be another markup range, instead of it
 	being the negative toggle.  By removing the processed codes, we
 	avoid this issue.  This reverts the functionality removed in
 	946ceca2, and therefore also re-adds the check to make an
@@ -20897,7 +20897,7 @@
 	Define compiler macros for /=, atom and nlistp
 
 	Calls to these functions were previously rewritten in terms of other
-	functions both in the optimiser and during codegen, for no good reason.
+	functions both in the optimizer and during codegen, for no good reason.
 
 	This also resulted in poor diagnostics: wrong-arity calls to 'atom' and
 	'nlistp' produced doubled but slightly-different warnings, and no
@@ -20911,11 +20911,11 @@
 
 2025-10-30  Mattias Engdegård  <[email protected]>
 
-	Fix numeric comparison bug when optimisation is disabled
+	Fix numeric comparison bug when optimization is disabled
 
 	* lisp/emacs-lisp/bytecomp.el (byte-compile-cmp):
-	Don't assume that N-ary comparisons have been normalised, which is done
-	in the optimiser.  Reported by Pip Cet.
+	Don't assume that N-ary comparisons have been normalized, which is done
+	in the optimizer.  Reported by Pip Cet.
 
 2025-10-30  Mattias Engdegård  <[email protected]>
 
@@ -20937,7 +20937,7 @@
 
 	* lisp/textmodes/markdown-ts-mode.el:
 	(markdown-ts--convert-code-block-language): Return nil if the
-	langauge doesn't have a corresponding major mode in
+	language doesn't have a corresponding major mode in
 	markdown-ts-code-block-source-mode-map.
 
 2025-10-30  Yuan Fu  <[email protected]>
@@ -21141,14 +21141,14 @@
 
 2025-10-24  Mattias Engdegård  <[email protected]>
 
-	Fix peephole optimiser bug for symbolp
+	Fix peephole optimizer bug for symbolp
 
 	* lisp/emacs-lisp/byte-opt.el (byte-optimize-lapcode):
 	Don't sink 'symbolp' past 'unbind'; it's unsafe.
 
 2025-10-24  Mattias Engdegård  <[email protected]>
 
-	Move some constants into the peephole optimiser
+	Move some constants into the peephole optimizer
 
 	* lisp/emacs-lisp/byte-opt.el (byte-tagref-ops, byte-conditional-ops)
 	(byte-after-unbind-ops, byte-compile-side-effect-and-error-free-ops)
@@ -22178,7 +22178,7 @@
 	Fix Tramp customization
 
 	Do not use the ;;;###tramp-autoload cookie for defcustoms.  This
-	damages the customisation when Tramp is autoloaded.  Reported by
+	damages the customization when Tramp is autoloaded.  Reported by
 	Joel Reicher <[email protected]>.
 
 	* lisp/net/tramp-cache.el (tramp-verbose): Declare.
@@ -24579,7 +24579,7 @@
 
 2025-09-07  Mattias Engdegård  <[email protected]>
 
-	Harmonise doc strings for {re-,posix-,}search-{forward,backward}
+	Harmonize doc strings for {re-,posix-,}search-{forward,backward}
 
 	The doc strings for re-search-forward and re-search-backward have been
 	improved (bug#25193, bug#31584) but the corresponding posix- and
@@ -26098,7 +26098,7 @@
 
 	The previous fix for this bug is an acceptable approach, but
 	more care must be taken when clearing a flymake--state object's
-	diagnostics.  Refactor this behaviour into a helper.
+	diagnostics.  Refactor this behavior into a helper.
 
 	* lisp/progmodes/flymake.el (flymake--clear-state): New helper.
 	(flymake--publish-diagnostics, flymake-start): Use it.
@@ -34561,7 +34561,7 @@
 
 	* lisp/emacs-lisp/package.el (package-unpack, package-dir-info):
 	Check the marked files if in a Dired buffer, and otherwise
-	fallback on the previous behaviour or if there was no selection.
+	fallback on the previous behavior or if there was no selection.
 	(package-install-from-buffer): Document the feature.
 	* etc/NEWS: Mention the change.
 
@@ -39020,7 +39020,7 @@
 
 2025-03-25  Philipp Stephani  <[email protected]>
 
-	Mimic behavior of 'aref' when signalling out-of-range errors.
+	Mimic behavior of 'aref' when signaling out-of-range errors.
 
 	The convention used by 'aref' and friends is that for
 	'args-out-of-range', the error data is a list (SEQ INDEX).  Use the same
@@ -39036,7 +39036,7 @@
 	'args-out-of-range' means that some index argument isn't valid for a
 	given sequence/range, which isn't the case here.  Instead, define a new
 	error symbol to mean "user-supplied buffer is too small."  Since we
-	never specified nor tested which error symbol was signalled in this
+	never specified nor tested which error symbol was signaled in this
 	case, changing it shouldn't cause severe breakages.
 
 	* src/emacs-module.c (module_buffer_too_small): New helper function.
@@ -44046,7 +44046,7 @@
 	type by default.
 	* doc/emacs/killing.texi (Clipboard):
 	* doc/lispref/frames.texi (Yanking Media): Document the new
-	behaviour, and the new variables.
+	behavior, and the new variables.
 	* etc/NEWS: Announce the change.  (Bug#75116)
 
 2025-02-22  Mauro Aranda  <[email protected]>
@@ -50187,7 +50187,7 @@
 
 	* lisp/progmodes/go-ts-mode.el (go-ts-mode-test-flags):
 	(go-ts-mode--get-test-flags): New custom variable and function
-	for controlling test behaviour.
+	for controlling test behavior.
 	(go-ts-mode--compile-test): Updated to use new test flags
 	variable for passing extra information to the go test command
 	line.
@@ -51504,13 +51504,13 @@
 	usability problem.  It is relatively too easy to mistakenly
 	launch the function and, if a region of text is selected, have
 	potentially sensitive data sent out to a third-party service.
-	This commit changes the search function's default behaviour so
+	This commit changes the search function's default behavior so
 	that explicit confirmation is required before a region is sent
-	to a search engine.  The behaviour can be adjusted via the
+	to a search engine.  The behavior can be adjusted via the
 	newly-introduced 'eww-search-confirm-send-region' variable,
 	which is set to true by default.
 	* lisp/net/eww.el (eww-search-confirm-send-region): Add.
-	(eww-search-words): Update default 'eww-search-words' behaviour
+	(eww-search-words): Update default 'eww-search-words' behavior
 	so as to ask confirmation before sending the region to a search
 	engine.  (Bug#74218)
 
@@ -58890,7 +58890,7 @@
 
 	* lisp/vc/diff-mode.el (diff-vc-deduce-fileset): Signal
 	user-error when the buffer is narrowed.
-	* lisp/vc/vc.el (vc-next-action): Remove code signalling a
+	* lisp/vc/vc.el (vc-next-action): Remove code signaling a
 	user-error when the buffer is narrowed.
 
 2024-10-02  Stefan Kangas  <[email protected]>
@@ -59324,7 +59324,7 @@
 	(Finternal_set_lisp_face_attribute_from_resource)
 	(Finternal_get_lisp_face_attribute)
 	(Finternal_lisp_face_attribute_values, syms_of_xfaces):
-	Stop recognising :reverse-video.
+	Stop recognizing :reverse-video.
 	* etc/NEWS: Announce.
 
 2024-09-29  Mattias Engdegård  <[email protected]>
@@ -59787,7 +59787,7 @@
 	when the mode is activated.
 	(midnight-delay-set): Only start the timer if the mode is turned
 	on.  (Bug#73291)
-	* etc/NEWS: Document the change in behaviour.
+	* etc/NEWS: Document the change in behavior.
 
 2024-09-21  Stefan Kangas  <[email protected]>
 
@@ -60619,7 +60619,7 @@
 
 2024-09-09  Mattias Engdegård  <[email protected]>
 
-	* etc/emacs_lldb.py (Lisp_Object): Recognise Lisp_Sub_Char_Table
+	* etc/emacs_lldb.py (Lisp_Object): Recognize Lisp_Sub_Char_Table
 
 2024-09-09  Mattias Engdegård  <[email protected]>
 
@@ -63559,7 +63559,7 @@
 	Improve implementation of built-in Eshell "kill" command
 
 	* lisp/eshell/esh-proc.el (eshell/kill): Fix handling of commands like
-	"kill 123".  Use REMOTE when signalling PIDs in remote directories.
+	"kill 123".  Use REMOTE when signaling PIDs in remote directories.
 	Signal using process objects when possible.  Report errors when failing
 	to signal.
 
diff --git a/admin/nt/dist-build/README-windows-binaries b/admin/nt/dist-build/README-windows-binaries
index d901c9b00fa..fb2393c0f01 100644
--- a/admin/nt/dist-build/README-windows-binaries
+++ b/admin/nt/dist-build/README-windows-binaries
@@ -79,8 +79,8 @@ people who want to report bugs against the current master, to help in
 "pretesting" new release versions, and so on.
 
 The files follow the same naming convention, but also include a date
-(and sometimes information about their branch) or they may releate to a
-sepecific pretest or release candidate for an "uncut" Emacs.  Emacs
+(and sometimes information about their branch) or they may relate to a
+specific pretest or release candidate for an "uncut" Emacs.  Emacs
 sources are distributed along with each dated snapshot.  Sources are
 provided for the pretest and release candidate Emacs versions here, as
 for release builds, are found in the directory (or directories) above.
diff --git a/doc/lispref/display.texi b/doc/lispref/display.texi
index 0d0899e418c..5704103ced9 100644
--- a/doc/lispref/display.texi
+++ b/doc/lispref/display.texi
@@ -5946,7 +5946,7 @@ property, and put the margin display specification on the contents of
 the before-string.
 
   Note that if the string to be displayed in the margin doesn't fully
-specify its face, the nonspecified attributes are inherited from the
+specify its face, the unspecified attributes are inherited from the
 @code{margin} face (@pxref{Basic Faces}).  If you want a margin string
 to have a specific appearance independent of the @code{margin} face,
 make sure the string has a face specifying all required attributes.
diff --git a/doc/lispref/parsing.texi b/doc/lispref/parsing.texi
index dac6574a969..bd4e64cff34 100644
--- a/doc/lispref/parsing.texi
+++ b/doc/lispref/parsing.texi
@@ -2171,7 +2171,7 @@ underscore are ignored, and the @code{@@language} capture name is
 reserved.
 
 If the embedded language is dynamic, then @code{:embed} can specify a
-function rathar than a static language.  The function takes the node
+function rather than a static language.  The function takes the node
 captured with @code{@@language} capture name.  Care have to be taken that
 the @code{@@language} capture and the range capture are in the same
 match group.  The function should return either a language symbol, or nil
diff --git a/doc/misc/ChangeLog.1 b/doc/misc/ChangeLog.1
index 67fcf11ac28..a6ca46f0cb0 100644
--- a/doc/misc/ChangeLog.1
+++ b/doc/misc/ChangeLog.1
@@ -8562,7 +8562,7 @@
 	* doclicense.texi: Remove node heading, so that it can be included by
 	other files.
 
-	* dired-x.texi: Relicence under GFDL.  Remove date from title page.
+	* dired-x.texi: Relicense under GFDL.  Remove date from title page.
 
 	* calc.texi (Algebraic Tutorial): Emphasize that / binds less strongly
 	than *.
diff --git a/doc/misc/org.org b/doc/misc/org.org
index d4bf8cb009c..5b5434a9e50 100644
--- a/doc/misc/org.org
+++ b/doc/misc/org.org
@@ -14990,7 +14990,7 @@ set it to =toc=:
 #+cindex: LaTeX ToC export a la ~org~
 #+cindex: @samp{org-latex-toc-include-unnumbered}
 If you want the LaTeX exporter to behave like other exporters,
-customise the variable ~org-latex-toc-include-unnumbered~ and
+customize the variable ~org-latex-toc-include-unnumbered~ and
 set it to ~t~:
 
 #+begin_example
diff --git a/etc/ERC-NEWS b/etc/ERC-NEWS
index bc9669e7b59..c4926d2b8f0 100644
--- a/etc/ERC-NEWS
+++ b/etc/ERC-NEWS
@@ -34,7 +34,7 @@ skip messages from "fools" and those in untracked buffers.
 Option 'erc-desktop-notifications-ignored-when-focused' can spare users
 from being notified when interacting with the initiating buffer.
 
-** Apply options granularly to specific connections or buffers.
+** Apply options in detail to specific connections or buffers.
 Based on an idea drafted nearly a quarter century ago by ERC's earliest
 contributors, the 'settings' module offers a ready-made method for
 binding arbitrary user options to various "scopes" of interest.  It
diff --git a/etc/NEWS.31 b/etc/NEWS.31
index ffbc142cad1..dcc5cc65028 100644
--- a/etc/NEWS.31
+++ b/etc/NEWS.31
@@ -3378,7 +3378,7 @@ contents of the current buffer.
 When enabled, this displays indications about the availability of add-on
 ELPA packages for the current buffer and suggestions for installing
 those packages.  The default is to show a button on the mode line that
-can be used to install such packages, but you can customise the
+can be used to install such packages, but you can customize the
 presentation style of these suggestions using
 'package-autosuggest-style'.
 
diff --git a/lib-src/emacsclient.c b/lib-src/emacsclient.c
index 381481c7fbd..3446dce8008 100644
--- a/lib-src/emacsclient.c
+++ b/lib-src/emacsclient.c
@@ -2297,7 +2297,7 @@ main (int argc, char **argv)
             }
           else if (strprefix ("-print ", p))
             {
-              /* -print STRING: Print STRING, preceeded by a newline, on
+              /* -print STRING: Print STRING, preceded by a newline, on
                   the terminal. */
 	      if (!suppress_output)
 		{
@@ -2310,7 +2310,7 @@ main (int argc, char **argv)
           else if (strprefix ("-print-nonl ", p))
             {
               /* -print-nonl STRING: Print STRING on the terminal
-                 without a preceding newlin.  Used to continue a
+                 without a preceding newline.  Used to continue a
                  preceding -print command.  Nowadays used only for
                  servers in Emacs versions before 31.  */
 	      if (!suppress_output)
diff --git a/lisp/calendar/diary-icalendar.el b/lisp/calendar/diary-icalendar.el
index 33d8768bbb5..bd0daf1c73b 100644
--- a/lisp/calendar/diary-icalendar.el
+++ b/lisp/calendar/diary-icalendar.el
@@ -467,7 +467,7 @@ matches lines like:
       (one-or-more space)
       "Status:"
       (zero-or-more space)
-      (group-n 1 (or "tentative" "confirmed" "cancelled" "needs-action" "completed"
+      (group-n 1 (or "tentative" "confirmed" "canceled" "needs-action" "completed"
                      "in-process" "draft" "final")))
   "Regular expression to match status of an event.
 
diff --git a/lisp/calendar/icalendar-parser.el b/lisp/calendar/icalendar-parser.el
index d08dce88e8b..5880081201a 100644
--- a/lisp/calendar/icalendar-parser.el
+++ b/lisp/calendar/icalendar-parser.el
@@ -2885,7 +2885,7 @@ facilitate parsing that property."
 
 This property is a keyword used by an Organizer to inform
 Attendees about the status of a component, e.g. whether an
-`icalendar-vevent' has been cancelled, whether an
+`icalendar-vevent' has been canceled, whether an
 `icalendar-vtodo' has been completed, or whether an
 `icalendar-vjournal' is still in draft form.  It can be specified
 at most once on these components."
diff --git a/lisp/cedet/semantic/db-find.el b/lisp/cedet/semantic/db-find.el
index 27405c5c405..53b4c90de54 100644
--- a/lisp/cedet/semantic/db-find.el
+++ b/lisp/cedet/semantic/db-find.el
@@ -212,7 +212,7 @@ This class will cache data derived during various searches.")
   "Synchronize the search index IDX with some NEW-TAGS."
   ;; Reset our parts.
   (semantic-reset idx)
-  ;; Notify dependants by clearing their indices.
+  ;; Notify dependents by clearing their indices.
   (semanticdb-notify-references
    (oref idx table)
    (lambda (tab _me)
@@ -226,7 +226,7 @@ This class will cache data derived during various searches.")
   (if (semantic-find-tags-by-class 'include new-tags)
       (progn
 	(semantic-reset idx)
-	;; Notify dependants by clearing their indices.
+	;; Notify dependents by clearing their indices.
 	(semanticdb-notify-references
 	 (oref idx table)
 	 (lambda (tab _me)
@@ -236,7 +236,7 @@ This class will cache data derived during various searches.")
     (when (oref idx type-cache)
       (when (semanticdb-partial-synchronize (oref idx type-cache) new-tags)
 	;; If the synchronize returns true, we need to notify.
-	;; Notify dependants by clearing their indices.
+	;; Notify dependents by clearing their indices.
 	(semanticdb-notify-references
 	 (oref idx table)
 	 (lambda (tab _me)
diff --git a/lisp/emacs-lisp/package-activate.el b/lisp/emacs-lisp/package-activate.el
index 5e2623c57f1..823ce88dcd4 100644
--- a/lisp/emacs-lisp/package-activate.el
+++ b/lisp/emacs-lisp/package-activate.el
@@ -533,7 +533,7 @@ the `Version:' header."
 
 ;;;; Package suggestions system
 
-;; Note that only the definitions necessary to recognise package
+;; Note that only the definitions necessary to recognize package
 ;; suggestions are defined here.  The user interface to select and act
 ;; on package suggestions is to be found in package.el.
 
diff --git a/lisp/emacs-lisp/package-vc.el b/lisp/emacs-lisp/package-vc.el
index 2641fafdcd9..bd8203a76f3 100644
--- a/lisp/emacs-lisp/package-vc.el
+++ b/lisp/emacs-lisp/package-vc.el
@@ -738,7 +738,7 @@ attribute in PKG-SPEC."
               (let* ((remove (seq-remove
                               #'file-exists-p
                               (let ((default-directory dir))
-                                (mapcar #'expand-file-name '("REAME-elpa"))))))
+                                (mapcar #'expand-file-name '("README-elpa"))))))
                 (copy-directory
                  (file-name-as-directory (package-desc-dir prev-desc))
                  (file-name-as-directory dir)
diff --git a/lisp/emacs-lisp/package.el b/lisp/emacs-lisp/package.el
index e2cbd631f90..bdfad4d107c 100644
--- a/lisp/emacs-lisp/package.el
+++ b/lisp/emacs-lisp/package.el
@@ -1860,7 +1860,7 @@ Used to populate `package-selected-packages'."
   "Set `package-selected-packages' to VALUE.
 During initialization, we record VALUE but to not persist it using
 Customize, to avoid overwriting configurations that haven't yet been
-loaded.  After initisation we update the user option directly."
+loaded.  After initialization we update the user option directly."
   (when (or value after-init-time)
     ;; It is valid to set it to nil, for example when the last package
     ;; is uninstalled.  But it shouldn't be done at init time, to avoid
diff --git a/lisp/emacs-lisp/rx.el b/lisp/emacs-lisp/rx.el
index 7b2bbe8fb11..0273c7168ab 100644
--- a/lisp/emacs-lisp/rx.el
+++ b/lisp/emacs-lisp/rx.el
@@ -295,7 +295,7 @@ Left-fold the list L, starting with X, by the binary function F."
 ;;  (or "a" (seq "ab" (seq "c" "d") "")) -> (or "a" "abcd")
 
 ;; FIXME: Since `rx--normalize-char-pattern' recurses through `or', `not' and
-;; `intersection', we may end up normalising subtrees multiple times
+;; `intersection', we may end up normalizing subtrees multiple times
 ;; which wastes time (but should be idempotent).
 ;; One way to avoid this is to aggressively normalize the entire tree
 ;; before translating anything at all, but we must then recurse through
diff --git a/lisp/erc/erc-common.el b/lisp/erc/erc-common.el
index 481b6084a6a..7f1a3c6354d 100644
--- a/lisp/erc/erc-common.el
+++ b/lisp/erc/erc-common.el
@@ -437,7 +437,7 @@ if ARG is omitted or nil.
 (defmacro erc-with-initialized-session (&rest body)
   "Run BODY in all ERC buffers if outside `erc-open' and soon otherwise.
 When inside `erc-open', run BODY after session variables have been
-initialzied and after all `erc-mode-hook' members but before any
+initialized and after all `erc-mode-hook' members but before any
 `after-change-major-mode-hook' members.  Expect caller to know this is
 only useful in global-module setup and that they're still responsible
 for teardown, which is often done with `erc-buffer-do' or similar."
diff --git a/lisp/language/indonesian.el b/lisp/language/indonesian.el
index e9aac5e615f..b90fc134e23 100644
--- a/lisp/language/indonesian.el
+++ b/lisp/language/indonesian.el
@@ -125,7 +125,7 @@ Buginese language and its script Lontara are supported in this language environm
       (independent-vowel    "[\xA984-\xA98E]")
       (telu                 "\xA9B3")
       (vowel                "[\xA9B4-\xA9BC]")
-      (dependant-consonant  "[\xA9BD-\xA9BF]")
+      (dependent-consonant  "[\xA9BD-\xA9BF]")
       (modifier-above       "[\xA980-\xA983]")
       (pangkon              "\xA9C0"))
   (set-char-table-range composition-function-table
@@ -134,19 +134,19 @@ Buginese language and its script Lontara are supported in this language environm
                                ;; Consonant based syllables
                                (concat consonant telu "?\\(?:" pangkon consonant
                                        telu "?\\)*\\(?:" pangkon "\\|" vowel "*" telu
-                                       "?" modifier-above "?" dependant-consonant "?\\)")
+                                       "?" modifier-above "?" dependent-consonant "?\\)")
                                1 'font-shape-gstring)
                               (vector
                                ;; Vowels based syllables
                                (concat independent-vowel telu "?" pangkon "?"
-                                       vowel "?" modifier-above "?" dependant-consonant "?")
+                                       vowel "?" modifier-above "?" dependent-consonant "?")
                                1 'font-shape-gstring))))
 
 ;; Sundanese composition rules
 (let ((consonant            "[\x1B8A-\x1BA0\x1BAE\x1BAF\x1BBB-\x1BBF]")
       (independent-vowel    "[\x1B83-\x1B89]")
       (vowel                "[\x1BA4-\x1BA9]")
-      (dependant-consonant  "[\x1BA1-\x1BA3\x1BAC-\x1BAD]")
+      (dependent-consonant  "[\x1BA1-\x1BA3\x1BAC-\x1BAD]")
       (modifier-above       "[\x1B80-\x1B82]")
       (virama               "[\x1BAA\x1BAB]"))
   (set-char-table-range composition-function-table
@@ -155,18 +155,18 @@ Buginese language and its script Lontara are supported in this language environm
                                ;; Consonant based syllables
                                (concat consonant "\\(?:" virama consonant
                                        "\\)*\\(?:" virama "\\|" vowel "*"
-                                       modifier-above "?" dependant-consonant "?\\)")
+                                       modifier-above "?" dependent-consonant "?\\)")
                                1 'font-shape-gstring)
                               (vector
                                ;; Vowels based syllables
                                (concat independent-vowel virama "?"
-                                       vowel "?" modifier-above "?" dependant-consonant "?")
+                                       vowel "?" modifier-above "?" dependent-consonant "?")
                                1 'font-shape-gstring))))
 
 ;; Batak composition rules
 (let ((akshara              "[\x1BC0-\x1BE5]")
       (vowel                "[\x1BE7-\x1BEF]")
-      (dependant-consonant  "[\x1BF0\x1BF1]")
+      (dependent-consonant  "[\x1BF0\x1BF1]")
       (modifier-above       "\x1BE6")
       (virama               "[\x1BF2\x1BF3]"))
   (set-char-table-range composition-function-table
@@ -174,20 +174,20 @@ Buginese language and its script Lontara are supported in this language environm
                         (list (vector
                                ;; Akshara based syllables
                                (concat akshara virama "?" vowel "*" modifier-above
-                                       "?" dependant-consonant "?")
+                                       "?" dependent-consonant "?")
                                1 'font-shape-gstring))))
 
 ;; Rejang composition rules
 (let ((akshara              "[\xA930-\xA946]")
       (vowel                "[\xA947-\xA94E]")
-      (dependant-consonant  "[\xA94F\xA952]")
+      (dependent-consonant  "[\xA94F\xA952]")
       (virama               "\xA953"))
   (set-char-table-range composition-function-table
                         '(#xA947 . #xA953)
                         (list (vector
                                ;; Akshara based syllables
                                (concat akshara virama "?" vowel "*"
-                                       dependant-consonant "?")
+                                       dependent-consonant "?")
                                1 'font-shape-gstring))))
 
 ;; Makasar composition rules
diff --git a/lisp/obsolete/gnus-dbus.el b/lisp/obsolete/gnus-dbus.el
index a62cf8a0f97..e70beb4d8fe 100644
--- a/lisp/obsolete/gnus-dbus.el
+++ b/lisp/obsolete/gnus-dbus.el
@@ -41,8 +41,8 @@
 ;;   :group 'gnus-dbus
 ;;   :type 'boolean)
 
-;; It is suggested in the elisp documention that we create variable
-;; alias's before executing the `defcustom'.  To reliably accomplish
+;; It is suggested in the elisp documentation that we create variable
+;; aliases before executing the `defcustom'.  To reliably accomplish
 ;; that in this case we would have to edit gnus-start.el which I don't
 ;; want to do.  So I've done this instead.
 (require 'gnus-start) ;; Run defcustom for `gnus-close-on-sleep'
diff --git a/lisp/org/org-element.el b/lisp/org/org-element.el
index 32edc154132..d55669ad205 100644
--- a/lisp/org/org-element.el
+++ b/lisp/org/org-element.el
@@ -5027,7 +5027,7 @@ If narrowing is in effect, only parse the visible part of the
 buffer.
 
 This function assumes that current major mode is `org-mode'.  When the
-major mode is different, the behaviour is undefined.
+major mode is different, the behavior is undefined.
 
 Optional argument GRANULARITY determines the depth of the
 recursion.  It can be set to the following symbols:
diff --git a/lisp/org/ox-latex.el b/lisp/org/ox-latex.el
index d07af9e63ad..f2474cbdff6 100644
--- a/lisp/org/ox-latex.el
+++ b/lisp/org/ox-latex.el
@@ -1552,7 +1552,7 @@ calling `org-latex-compile'."
 (defcustom org-latex-toc-include-unnumbered nil
   "Whether to include unnumbered headings in the table of contents.
 
-The default behaviour is to include numbered headings only, as it is
+The default behavior is to include numbered headings only, as it is
 usually the case in LaTeX (but different from other Org exporters).
 To include an unnumbered heading, set the `:UNNUMBERED:'
 property to `toc'"
@@ -1983,7 +1983,7 @@ INFO is a plist used as a communication channel."
 (defcustom org-latex-use-sans nil
   "Whether to typeset the document with the Sans font family.
 
-The default behaviour is to typeset with the Roman font family."
+The default behavior is to typeset with the Roman font family."
   :group 'org-export-latex
   :package-version '(Org . "9.8")
   :type 'boolean
diff --git a/lisp/progmodes/compile.el b/lisp/progmodes/compile.el
index 593f9867533..d10a0d9b100 100644
--- a/lisp/progmodes/compile.el
+++ b/lisp/progmodes/compile.el
@@ -2851,7 +2851,7 @@ Optional arg DIFFERENT-FILE, if non-nil, means find next error for a
 file that is different from the current one.
 Optional arg PT, if non-nil, specifies the value of point to start
 looking for the next message.
-In interacvtive invocations, DIFFERENT-FILE and PT are always nil."
+In interactive invocations, DIFFERENT-FILE and PT are always nil."
   (interactive "p")
   (or (compilation-buffer-p (current-buffer))
       (error "Not in a compilation buffer"))
diff --git a/lisp/progmodes/eglot.el b/lisp/progmodes/eglot.el
index b27d7761111..1c9569434cf 100644
--- a/lisp/progmodes/eglot.el
+++ b/lisp/progmodes/eglot.el
@@ -2062,7 +2062,7 @@ Unless IMMEDIATE, send pending changes before making request."
 
 (defvar-local eglot--inflight-async-requests nil
   "An plist of symbols to lists of JSONRPC ids.
-The ids designate in-flight asynchronous requests that may be cancelled
+The ids designate in-flight asynchronous requests that may be canceled
 according to `eglot-advertise-cancellation'.")
 
 (cl-defun eglot--cancel-inflight-async-requests
diff --git a/lisp/subr.el b/lisp/subr.el
index 60a57688f73..a4705488540 100644
--- a/lisp/subr.el
+++ b/lisp/subr.el
@@ -6070,7 +6070,7 @@ Modifies the match data; use `save-match-data' if necessary."
                  (< start len)))))
     ;; field after last separator, if any
     (let ((item (if (= start 0)
-                    string    ; optimisation when there is no separator
+                    string    ; optimization when there is no separator
                   (substring string start))))
       (when trim
         (let* ((item-beg (if (string-match trim-left-re item 0)
diff --git a/lisp/textmodes/fill.el b/lisp/textmodes/fill.el
index 270cb388971..f8fe7cf0793 100644
--- a/lisp/textmodes/fill.el
+++ b/lisp/textmodes/fill.el
@@ -95,7 +95,7 @@ With a prefix argument, cancel the fill prefix."
         (setq fill-prefix nil))))
   (if fill-prefix
       (message "fill-prefix: \"%s\"" fill-prefix)
-    (message "fill-prefix cancelled")))
+    (message "fill-prefix canceled")))
 
 (defcustom adaptive-fill-mode t
   "Non-nil means determine a paragraph's fill prefix from its text."
diff --git a/lisp/textmodes/markdown-ts-mode-x.el b/lisp/textmodes/markdown-ts-mode-x.el
index 1296e3567a3..c3e18cec265 100644
--- a/lisp/textmodes/markdown-ts-mode-x.el
+++ b/lisp/textmodes/markdown-ts-mode-x.el
@@ -699,7 +699,7 @@ If optional REMOVE is non-nil, remove tables including their templates."
     ;; Convert markers to absolute positions.
     (setq beg (if (markerp beg) (marker-position beg) beg))
     (setq end (if (markerp end) (marker-position end) end))
-    ;; NOTE: Operate on the widened buffer to avoid treesiter crash issues.
+    ;; NOTE: Operate on the widened buffer to avoid treesitter crash issues.
     (without-restriction
       (let ((tocs)
             (beg-pos beg)
@@ -914,7 +914,7 @@ tables not being processed when this function is called."
     ;; Convert markers to absolute positions.
     (setq beg (if (markerp beg) (marker-position beg) beg))
     (setq end (if (markerp end) (marker-position end) end))
-    ;; NOTE: Operate on the widened buffer to avoid treesiter crash issues.
+    ;; NOTE: Operate on the widened buffer to avoid treesitter crash issues.
     (without-restriction
       (let ((tocs (markdown-ts--tocs beg end)))
         (unless tocs
diff --git a/lisp/vc/vc.el b/lisp/vc/vc.el
index 8fa0c661f93..8c924ee1265 100644
--- a/lisp/vc/vc.el
+++ b/lisp/vc/vc.el
@@ -4862,7 +4862,7 @@ to the working revision (except for keyword expansion)."
                                (format (ngettext "%d file" "%d files"
                                                  nfiles)
                                        nfiles)))))
-	    (error "Revert cancelled")))
+	    (error "Revert canceled")))
       (when diff-buffer
 	(quit-windows-on diff-buffer (eq vc-revert-show-diff 'kill))))
     (vc-revert-files backend files)))
diff --git a/m4/texinfo.m4 b/m4/texinfo.m4
index 231d0b35736..c861e8bb315 100644
--- a/m4/texinfo.m4
+++ b/m4/texinfo.m4
@@ -58,8 +58,8 @@ fi
 ]AC_SUBST([DOCMISC_W32])
 ])
 dnl
-dnl gl_dollar is needed for $1, $2 etc. in AWK snippets not to be intepreted by
-dnl M4 as macros arguments.
+dnl gl_dollar is needed for $1, $2 etc. in AWK snippets not to be interpreted by
+dnl M4 as macro arguments.
 m4_define([gl_dollar],[m4_quote([$])])dnl
 m4_define([gl_DOCLANGS_FULL],[[default fr]])dnl
 dnl This is minimal texinfo.tex version with "-" removed from the ISO date
@@ -68,10 +68,10 @@ dnl language/encoding corresponding locale is not installer nor active.
 dnl See texinfo version 836b8924560.
 m4_define([gl_TEXINFO_TEX_MINVER],[[20260426.12]])dnl
 m4_define([gl_TEXINDEX_MINVER],[[7.1]])dnl
-m4_define([gl_TEXINFO_INDEXING_IS_LOCALE_DEPENDANT],[dnl
+m4_define([gl_TEXINFO_INDEXING_IS_LOCALE_DEPENDENT],[dnl
 [DOCLANGS='default'
 gl_fn_doclangs_info () {]
-  AC_MSG_WARN([texinfo.tex/texindex versions suggest that indexing is locale dependant, manual compilation is restricted to lang 'default', override this by setting DOCLANGS in the environment])
+  AC_MSG_WARN([texinfo.tex/texindex versions suggest that indexing is locale dependent, manual compilation is restricted to lang 'default', override this by setting DOCLANGS in the environment])
 [}]])dnl
 m4_define([gl_GET_TEXINFO_TEX_VER],[dnl
 [texinfo_tex_ver=`tex -jobname=conftest '\nonstopmode\input texinfo.tex @typeout{TEXINFO_TEX_VER=@texinfoversion}@bye' | awk 'BEGIN{R=1;FS="="};]gl_dollar[1=="TEXINFO_TEX_VER" { gsub("-","");print ]gl_dollar[2; R=0; exit}; END{ exit R}'`
@@ -92,7 +92,7 @@ if test $? -ne 0; then
 ])dnl
 AC_DEFUN([gl_TEXINFO_VERSION_COMPARE],[dnl
 AC_REQUIRE([AS_VERSION_COMPARE])
-AS_VERSION_COMPARE([$1],[$2],[gl_TEXINFO_INDEXING_IS_LOCALE_DEPENDANT()],[$3],[$3])dnl
+AS_VERSION_COMPARE([$1],[$2],[gl_TEXINFO_INDEXING_IS_LOCALE_DEPENDENT()],[$3],[$3])dnl
 ])dnl
 dnl gl_SET_DOCLANGS
 AC_DEFUN([gl_SET_DOCLANGS],[dnl
@@ -107,7 +107,7 @@ gl_TEXINFO_VERSION_COMPARE([$texinfo_tex_ver],[gl_TEXINFO_TEX_MINVER()],[dnl
   gl_TEXINFO_VERSION_COMPARE([$texindex_ver],[gl_TEXINDEX_MINVER()],[dnl
   [DOCLANGS=']gl_DOCLANGS_FULL()['
   gl_fn_doclangs_info () {]
-    AC_MSG_NOTICE([texinfo.tex/texindex versions suggest that indexing is not locale dependant])
+    AC_MSG_NOTICE([texinfo.tex/texindex versions suggest that indexing is not locale dependent])
   [}]])
 ])
 AC_MSG_RESULT([[']$DOCLANGS[']])
diff --git a/src/term.c b/src/term.c
index 8777a3b6a65..7e05f5b5139 100644
--- a/src/term.c
+++ b/src/term.c
@@ -4652,7 +4652,7 @@ use the Bourne shell command 'TERM=...; export TERM' (C-shell:\n\
 	       setaf and setab treat them as the first eight indexed
 	       ANSI colors. */
 	  }
-	/* Fall back to direct colour by RGB value (semicolon version)
+	/* Fall back to direct color by RGB value (semicolon version)
 	   if Tc is set (de-facto standard introduced by tmux) or if
 	   requested by the COLORTERM environment variable.  */
 	else if ((tigetflag ("Tc") > 0)
diff --git a/src/treesit.c b/src/treesit.c
index edf728e04fa..d5f58c5416d 100644
--- a/src/treesit.c
+++ b/src/treesit.c
@@ -642,7 +642,7 @@ struct treesit_loaded_lang
    so it stays stable for the whole session.  */
 struct treesit_lang_cache_entry
 {
-  /* Symbol for the cached langauge, never gc'ed.  */
+  /* Symbol for the cached language, never gc'ed.  */
   Lisp_Object symbol;
   /* The cached language object.  */
   struct treesit_loaded_lang lang;
diff --git a/src/window.c b/src/window.c
index 78a5a4436f1..785c71b3569 100644
--- a/src/window.c
+++ b/src/window.c
@@ -2328,7 +2328,7 @@ The return value is a list of elements (BUFFER WINDOW-START POS),
 where BUFFER is a buffer, WINDOW-START is the start position of the
 window for that buffer, and POS is a window-specific point value.
 
-In rare ocasions BUFFER may have been already killed.  It's therefore
+In rare occasions BUFFER may have been already killed.  It's therefore
 advisable to always check the return value for the occurrence of dead
 buffers before using it.  */)
   (Lisp_Object window)
diff --git a/src/xdisp.c b/src/xdisp.c
index 6f44461f170..f01ed8cb053 100644
--- a/src/xdisp.c
+++ b/src/xdisp.c
@@ -1082,7 +1082,7 @@ bool display_working_on_window_p;
    line, in particular when called from non-redisplay code (so
    redisplaying_p is false).  We inhibit resizing of the frames during
    that time, because that could change glyph_row pointers in the glyph
-   matrix behind the back of teh code which manipulates these pointers.  */
+   matrix behind the back of the code which manipulates these pointers.  */
 int dont_resize_frames;
 
 /* If a string, XTread_socket generates an event to display that string.
diff --git a/src/xterm.c b/src/xterm.c
index c9e7121692b..42b72ad71e9 100644
--- a/src/xterm.c
+++ b/src/xterm.c
@@ -28559,7 +28559,7 @@ x_suspend_background_fills (struct frame *f)
   XSetWindowBackgroundPixmap (dpy, FRAME_X_WINDOW (f), None);
 }
 
-/* No automatmic fill happens when the background is restored.  */
+/* No automatic fill happens when the background is restored.  */
 static void
 x_restore_background_fills (struct frame *f)
 {
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
diff --git a/admin/nt/dist-build/build-dep-zips.py b/admin/nt/dist-build/build-dep-zips.py
index 493e7616fa9..43b4b4eb418 100755
--- a/admin/nt/dist-build/build-dep-zips.py
+++ b/admin/nt/dist-build/build-dep-zips.py
@@ -30,7 +30,7 @@ EMACS_MAJOR_VERSION= os.getenv('EMACS_MAJOR_VERSION') or "31"
 # Base URI for the package sources mapped in PKG_REQ
 SRC_REPO="https://repo.msys2.org/mingw/sources"
 
-# Map items in `dynamic-library-alist' to source pakages
+# Map items in `dynamic-library-alist' to source packages.
 PKG_REQ='''mingw-w64-x86_64-giflib
 mingw-w64-x86_64-gnutls
 mingw-w64-x86_64-harfbuzz
@@ -47,7 +47,7 @@ mingw-w64-x86_64-xpm-nox
 mingw-w64-x86_64-tree-sitter
 mingw-w64-x86_64-sqlite3'''.split()
 
-# Emacs style path to dependancy DLLs on build system
+# Emacs style path to dependency DLLs on build system
 DLL_SRC="mingw64"
 OUT_TAG=""
 
@@ -95,7 +95,7 @@ def gather_deps():
     print("Deps updated in", os.getcwd(), "as", zipfile)
     os.chdir("../")
 
 # Return dependancies listed in Emacs
 def init_deps():
     return '''libXpm-nox4.dll
 libpng16-16.dll
@@ -315,7 +315,7 @@ parser.add_argument("-d", help="dry run",
 parser.add_argument("-l", help="list dependencies",
                     action="store_true")
 
-parser.add_argument("-e", help="extract direct dependancies",
+parser.add_argument("-e", help="extract direct dependencies",
                     action="store_true")
 
 args = parser.parse_args()
@@ -95,7 +95,7 @@ def gather_deps():
     os.chdir("../")
 
-# Return dependancies listed in Emacs
+# Return dependencies listed in Emacs.
 def init_deps():
     return '''libXpm-nox4.dll
diff --git a/lisp/custom.el b/lisp/custom.el
index 91d3a923709..6779ca38134 100644
--- a/lisp/custom.el
+++ b/lisp/custom.el
@@ -1132,17 +1132,17 @@ arguments to `custom-theme-set-variables'.  Return the sorted
 list, in which A occurs before B if B was defined with a
 `:set-after' keyword specifying A (see `defcustom')."
   (let ((custom--sort-vars-table (make-hash-table))
-	(dependants (make-hash-table))
+	(dependents (make-hash-table))
 	(custom--sort-vars-result nil)
 	last)
     ;; Construct a pair of tables keyed with the symbols of VARS.
     (dolist (var vars)
       (puthash (car var) (cons t var) custom--sort-vars-table)
-      (puthash (car var) var dependants))
+      (puthash (car var) var dependents))
     ;; From the second table, remove symbols that are depended-on.
     (dolist (var vars)
       (dolist (dep (get (car var) 'custom-dependencies))
-	(remhash dep dependants)))
+	(remhash dep dependents)))
     ;; If a variable is "stand-alone", put it last if it's a minor
     ;; mode or has a :require flag.  This is not really necessary, but
     ;; putting minor modes last helps ensure that the mode function
@@ -1152,25 +1152,25 @@ list, in which A occurs before B if B was defined with a
 			  (or (nth 3 var)
 			      (eq (get sym 'custom-set)
 				  'custom-set-minor-mode)))
-		 (remhash sym dependants)
+		 (remhash sym dependents)
 		 (push var last)))
-	     dependants)
+	     dependents)
     ;; The remaining symbols depend on others but are not
     ;; depended-upon.  Do a depth-first topological sort.
-    (maphash #'custom--sort-vars-1 dependants)
+    (maphash #'custom--sort-vars-1 dependents)
     (nreverse (append last custom--sort-vars-result))))
 
 (defun custom--sort-vars-1 (sym &optional _ignored)
   (let ((elt (gethash sym custom--sort-vars-table)))
     ;; The car of the hash table value is nil if the variable has
     ;; already been processed, `dependant' if it is a dependant in the
     ;; current graph descent, and t otherwise.
     (when elt
       (cond
-       ((eq (car elt) 'dependant)
+       ((eq (car elt) 'dependent)
 	(error "Circular custom dependency on `%s'" sym))
        ((car elt)
-	(setcar elt 'dependant)
+	(setcar elt 'dependent)
 	(dolist (dep (get sym 'custom-dependencies))
 	  (custom--sort-vars-1 dep))
 	(setcar elt nil)
@@ -1152,25 +1152,25 @@ list, in which A occurs before B if B was defined with a
   (let ((elt (gethash sym custom--sort-vars-table)))
     ;; The car of the hash table value is nil if the variable has
-    ;; already been processed, `dependant' if it is a dependant in the
+    ;; already been processed, `dependent' if it is a dependent in the
     ;; current graph descent, and t otherwise.
     (when elt